Automaton_Group = Automaton:NewModule("Group", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")
Automaton.options.args.group = {
	type = 'group',
	name = 'Group',
	desc = 'Options for accepting or declining group invites.',
	args = {
		toggle = {
			type = 'toggle',
			name = 'Enabled',
			desc = 'Accepts party invites from your friends or guild members automatically.',
			get = function() return Automaton:IsModuleActive("Group") end,
			set = function(v) Automaton:ToggleModuleActive("Group", v) end,
		},
		who = {
			type = 'toggle',
			name = 'Who',
			desc = 'Perform a /who on incoming party invites from unknown sources.',
			get = function() return Automaton.db.profile.autoGroupWho end,
			set = function(v) Automaton.db.profile.autoGroupWho = v end,
		},
		decline = {
			type = 'toggle',
			name = 'Decline',
			desc = 'Decline party invites from unknown sources.',
			get = function() return Automaton.db.profile.autoGroupDecline end,
			set = function(v) Automaton.db.profile.autoGroupDecline = v end,
		},
	}
}

function Automaton_Group:OnEnable()
	Automaton_Group:RegisterEvent("PARTY_INVITE_REQUEST")
end

function Automaton_Group:PARTY_INVITE_REQUEST()
	self:Debug("Processing AutoGroup")
	local who = arg1
	local acceptFrom = {}

	for i=1,GetNumGuildMembers() do
		local name = GetGuildRosterInfo(i)
		tinsert(acceptFrom,name)
	end

	for i=1,GetNumFriends() do
		local name = GetFriendInfo(i)
		tinsert(acceptFrom,name)
	end

	if foreachi(acceptFrom, function(i,v) if v==who then return true end end) then
		self:Debug("AutoGroup is accepting an invite from ".. who)
		AcceptGroup()
		StaticPopup_Hide("PARTY_INVITE")
		return
	end
	
	if Automaton.db.profile.autoGroupDecline then
		self:Print("Declining party invitation...")
		DeclineGroup()
		StaticPopup_Hide("PARTY_INVITE")
	elseif Automaton.db.profile.autoGroupWho then
		SendWho("n-\""..who.."\"")
	end
end